import pymongo
from django.db.backends.base.base import BaseDatabaseWrapper
from .creation import DatabaseCreation  # Importa la clase DatabaseCreation


class DatabaseClient:
    """
    A simple client class to handle MongoDB connections.
    """

    def __init__(self, connection):
        self.connection = connection


class DatabaseWrapper(BaseDatabaseWrapper):
    vendor = 'mongodb'
    display_name = 'MongoLight'
    client_class = DatabaseClient  # Clase para manejar la conexión
    # Clase para manejar la creación de la base de datos
    creation_class = DatabaseCreation

    def __init__(self, settings_dict, *args, **kwargs):
        super().__init__(settings_dict, *args, **kwargs)
        self.client = None
        self.connection = None

    def get_connection_params(self):
        return {
            'host': self.settings_dict['HOST'],
            'port': int(self.settings_dict.get('PORT', 27017)),
            'username': self.settings_dict.get('USER', ''),
            'password': self.settings_dict.get('PASSWORD', ''),
            'authSource': self.settings_dict.get('AUTH_SOURCE', 'admin'),
        }

    def create_cursor(self, name=None):
        return None  # MongoDB doesn't use cursors

    def _connect(self):
        if self.connection is None:
            connection_params = self.get_connection_params()
            self.client = pymongo.MongoClient(**connection_params)
            self.connection = self.client[self.settings_dict['NAME']]
        return self.connection



from django.db.backends.base.operations import BaseDatabaseOperations


class DatabaseOperations(BaseDatabaseOperations):
    compiler_module = "mongolight.compiler"

    def sql_flush(self, style, tables, reset_sequences, allow_cascade=False):
        for table in tables:
            self.connection[table].delete_many({})
        return []



from setuptools import setup, find_packages

setup(
    name="django-mongolight",
    version="0.1.3",
    author="Bryan Jesus Ramon Avila",
    author_email="bryanjesus.ra@gmail.com",
    description="A lightweight library for integrating Django with MongoDB.",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    url="https://github.com/bryancitu/django-mongolight",
    packages=find_packages(),
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.8",
    install_requires=[
        "Django >= 4.0",
        "pymongo >= 4.0",
    ],
)
